tlslite.integration.xmlrpcserver.TLSXMLRPCRequestHandler

Package tlslite :: Package integration :: Module xmlrpcserver :: Class TLSXMLRPCRequestHandler |
[hide private]
[frames] | no frames]

# Class TLSXMLRPCRequestHandler

source code

      SocketServer.BaseRequestHandler --+
                                        |
        SocketServer.StreamRequestHandler --+
                                            |
        BaseHTTPServer.BaseHTTPRequestHandler --+
                                                |
    SimpleXMLRPCServer.SimpleXMLRPCRequestHandler --+
                                                    |
                                                   TLSXMLRPCRequestHandler

XMLRPCRequestHandler using TLS

Nested Classes | [hide private]
Inherited from `BaseHTTPServer.BaseHTTPRequestHandler`: `MessageClass`

Instance Methods | [hide private]
do_POST(self) Handles the HTTPS POST request. | source code
setup(self) | source code
Inherited from `SimpleXMLRPCServer.SimpleXMLRPCRequestHandler`: `accept_encodings`, `decode_request_content`, `is_rpc_path_valid`, `log_request`, `report_404` Inherited from `BaseHTTPServer.BaseHTTPRequestHandler`: `address_string`, `date_time_string`, `end_headers`, `handle`, `handle_one_request`, `log_date_time_string`, `log_error`, `log_message`, `parse_request`, `send_error`, `send_header`, `send_response`, `version_string` Inherited from `SocketServer.StreamRequestHandler`: `finish` Inherited from `SocketServer.BaseRequestHandler`: `__init__`

Class Variables | [hide private]
Inherited from `SimpleXMLRPCServer.SimpleXMLRPCRequestHandler`: `aepattern`, `disable_nagle_algorithm`, `encode_threshold`, `rpc_paths`, `wbufsize` Inherited from `BaseHTTPServer.BaseHTTPRequestHandler`: `default_request_version`, `error_content_type`, `error_message_format`, `monthname`, `protocol_version`, `responses`, `server_version`, `sys_version`, `weekdayname` Inherited from `SocketServer.StreamRequestHandler`: `rbufsize`, `timeout`

Method Details | [hide private]

### do_POST(self) | source code
Handles the HTTPS POST request. Overrides: SimpleXMLRPCServer.SimpleXMLRPCRequestHandler.do_POST

### setup(self) | source code
Overrides: SocketServer.BaseRequestHandler.setup